@@ -79,6 +79,10 @@ class Token:
         else:
             self.attrs[idx][1] = self.attrs[idx][1] + " " + value
 
+    def copy(self):
+        """Return a shallow copy of the instance."""
+        return attr.evolve(self)
+
     def as_dict(self, children=True, filter=None, dict_factory=dict):
         """Return the token as a dict.
 
@@ -96,6 +100,13 @@ class Token:
             self, recurse=children, filter=filter, dict_factory=dict_factory
         )
 
+    @classmethod
+    def from_dict(cls, dct):
+        token = cls(**dct)
+        if token.children:
+            token.children = [cls.from_dict(c) for c in token.children]
+        return token
+
 
 @attr.s(slots=True)
 class NestedTokens:
@@ -128,6 +139,7 @@ def nest_tokens(tokens: List[Token]) -> List[Union[Token, NestedTokens]]:
         token = tokens.pop()
 
         if token.nesting == 0:
+            token = token.copy()
             output.append(token)
             if token.children:
                 token.children = nest_tokens(token.children)
