@@ -1,4 +1,3 @@
-import json
 from pathlib import Path
 from textwrap import dedent
 
@@ -9,6 +8,9 @@ from markdown_it.rules_inline import StateInline
 from markdown_it.rules_block import StateBlock
 from markdown_it.extensions.texmath import index as main
 from markdown_it.extensions.texmath import texmath_plugin
+from markdown_it.utils import read_fixture_file
+
+FIXTURE_PATH = Path(__file__).parent
 
 
 def test_inline_func():
@@ -79,58 +81,25 @@ def test_plugin_parse(data_regression):
     data_regression.check([t.as_dict() for t in tokens])
 
 
-def test_plugin_render():
-    md = MarkdownIt().use(texmath_plugin)
-    text = md.render(
-        dedent(
-            """\
-    $$
-    a=1 \\\\
-    b=2
-    $$ (abc)
-
-    - ab $c=1$ d
-    """
-        )
-    )
-    assert text == (
-        dedent(
-            """\
-    <section>
-    <eqn>
-    a=1 \\\\
-    b=2
-    </eqn>
-    </section>
-    <ul>
-    <li>ab <eq>c=1</eq> d</li>
-    </ul>
-    """
-        )
-    )
+@pytest.mark.parametrize(
+    "line,title,input,expected",
+    read_fixture_file(FIXTURE_PATH.joinpath("fixtures_dollar.md")),
+)
+def test_dollar_fixtures(line, title, input, expected):
+    md = MarkdownIt("commonmark").use(texmath_plugin)
+    md.options["xhtmlOut"] = False
+    text = md.render(input)
+    print(text)
+    assert text.rstrip() == expected.rstrip()
 
 
 @pytest.mark.parametrize(
-    "index,comment,src,valid",
-    [
-        [index, d["comment"], d["src"], d["valid"]]
-        for index, d in enumerate(
-            json.loads(Path(__file__).parent.joinpath("test_fixtures.json").read_text())
-        )
-    ],
+    "line,title,input,expected",
+    read_fixture_file(FIXTURE_PATH.joinpath("fixtures_bracket.md")),
 )
-def test_fixtures(index, comment, src, valid, data_regression):
-    md = MarkdownIt().use(texmath_plugin)
-    tokens = md.parse(src)
-    if tokens[0].type == "paragraph_open":
-        tokens = tokens[1:-1]
-    data_regression.check(
-        [t.as_dict() for t in tokens], basename=f"{index}_{str(valid)}_{comment[:15]}"
-    )
-
-
-# def test_a():
-#     md = MarkdownIt().use(texmath_plugin)
-#     tokens = md.parse("$1+1=\\n2$")
-#     print(tokens)
-#     raise
+def test_bracket_fixtures(line, title, input, expected):
+    md = MarkdownIt("commonmark").use(texmath_plugin, delimiters="brackets")
+    md.options["xhtmlOut"] = False
+    text = md.render(input)
+    print(text)
+    assert text.rstrip() == expected.rstrip()
